@@ -13,7 +13,7 @@
 
   COPYRIGHT:
 
-    (c) 2007-2012, martin isenburg, rapidlasso - fast tools to catch reality
+    (c) 2007-2019, martin isenburg, rapidlasso - fast tools to catch reality
 
     This is free software; you can redistribute and/or modify it under the
     terms of the GNU Lesser General Licence as published by the Free Software
@@ -30,6 +30,8 @@
 */
 #include "lasreader_bil.hpp"
 
+#include "lasvlrpayload.hpp"
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -123,7 +125,7 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
   if ((((creation.wYear)%4) == 0) && (creation.wMonth > 2)) header.file_creation_day++;
 #else
   header.file_creation_day = 333;
-  header.file_creation_year = 2012;
+  header.file_creation_year = 2019;
 #endif
 
   // initialize point format in header
@@ -332,6 +334,25 @@ BOOL LASreaderBIL::open(const CHAR* file_name)
     header.max_z = 0;
   }
 
+  // add the VLR for Raster LAZ 
+
+  LASvlrRasterLAZ vlrRasterLAZ;
+  vlrRasterLAZ.nbands = 1;
+  vlrRasterLAZ.nbits = 32;
+  vlrRasterLAZ.ncols = ncols;
+  vlrRasterLAZ.nrows = nrows;
+  vlrRasterLAZ.reserved1 = 0;
+  vlrRasterLAZ.reserved2 = 0;
+  vlrRasterLAZ.stepx = xdim;
+  vlrRasterLAZ.stepx_y = 0.0;
+  vlrRasterLAZ.stepy = ydim;
+  vlrRasterLAZ.stepy_x = 0.0;
+  vlrRasterLAZ.llx = ulxcenter - 0.5*xdim;
+  vlrRasterLAZ.lly = ulycenter + (0.5 - nrows)*ydim;
+  vlrRasterLAZ.sigmaxy = 0.0;
+
+  header.add_vlr("Raster LAZ", 7113, (U16)vlrRasterLAZ.get_payload_size(), vlrRasterLAZ.get_payload(), FALSE, "by LAStools of rapidlasso GmbH", FALSE);
+
   // reopen
 
   return reopen(file_name);
@@ -748,9 +769,18 @@ BOOL LASreaderBIL::read_point_default()
 
     if (elevation != nodata)
     {
-      point.set_x(ulxcenter + col * xdim);
-      point.set_y(ulycenter - row * ydim);
-      point.set_z(elevation);
+      if (!point.set_x(ulxcenter + col * xdim))
+      {
+        overflow_I32_x++;
+      }
+      if (!point.set_y(ulycenter - row * ydim))
+      {
+        overflow_I32_y++;
+      }
+      if (!point.set_z(elevation))
+      {
+        overflow_I32_z++;
+      }
       p_count++;
       col++;
       return TRUE;
@@ -770,6 +800,33 @@ ByteStreamIn* LASreaderBIL::get_stream() const
 
 void LASreaderBIL::close(BOOL close_stream)
 {
+  if (overflow_I32_x)
+  {
+#ifdef _WIN32
+    REprintf( "WARNING: total of %I64d integer overflows in x\n", overflow_I32_x);
+#else
+    REprintf( "WARNING: total of %lld integer overflows in x\n", overflow_I32_x);
+#endif
+    overflow_I32_x = 0;
+  }
+  if (overflow_I32_y)
+  {
+#ifdef _WIN32
+    REprintf( "WARNING: total of %I64d integer overflows in y\n", overflow_I32_y);
+#else
+    REprintf( "WARNING: total of %lld integer overflows in y\n", overflow_I32_y);
+#endif
+    overflow_I32_y = 0;
+  }
+  if (overflow_I32_z)
+  {
+#ifdef _WIN32
+    REprintf( "WARNING: total of %I64d integer overflows in z\n", overflow_I32_z);
+#else
+    REprintf( "WARNING: total of %lld integer overflows in z\n", overflow_I32_z);
+#endif
+    overflow_I32_z = 0;
+  }
   if (file)
   {
     fclose(file);
@@ -824,6 +881,9 @@ void LASreaderBIL::clean()
   nodata = -9999;
   floatpixels = FALSE;
   signedpixels = FALSE;
+  overflow_I32_x = 0;
+  overflow_I32_y = 0;
+  overflow_I32_z = 0;
 }
 
 LASreaderBIL::LASreaderBIL()
@@ -917,12 +977,12 @@ void LASreaderBIL::populate_bounding_box()
 {
   // compute quantized and then unquantized bounding box
 
-  F64 dequant_min_x = header.get_x(header.get_X(header.min_x));
-  F64 dequant_max_x = header.get_x(header.get_X(header.max_x));
-  F64 dequant_min_y = header.get_y(header.get_Y(header.min_y));
-  F64 dequant_max_y = header.get_y(header.get_Y(header.max_y));
-  F64 dequant_min_z = header.get_z(header.get_Z(header.min_z));
-  F64 dequant_max_z = header.get_z(header.get_Z(header.max_z));
+  F64 dequant_min_x = header.get_x((I32)(header.get_X(header.min_x)));
+  F64 dequant_max_x = header.get_x((I32)(header.get_X(header.max_x)));
+  F64 dequant_min_y = header.get_y((I32)(header.get_Y(header.min_y)));
+  F64 dequant_max_y = header.get_y((I32)(header.get_Y(header.max_y)));
+  F64 dequant_min_z = header.get_z((I32)(header.get_Z(header.min_z)));
+  F64 dequant_max_z = header.get_z((I32)(header.get_Z(header.max_z)));
 
   // make sure there is not sign flip
 
