@@ -64,10 +64,25 @@ BOOL LASwriterLAS::open(const char* file_name, const LASheader* header, U32 comp
     return FALSE;
   }
 
+#ifdef _MSC_VER
   file = fopen(file_name, "wb");
   if (file == 0)
   {
-    REprintf( "ERROR: cannot open file '%s'\n", file_name);
+    wchar_t* utf16_file_name = UTF8toUTF16(file_name);
+    file = _wfopen(utf16_file_name, L"wb");
+    if (file == 0)
+    {
+      REprintf( "ERROR: cannot open file '%ws' for write\n", utf16_file_name);
+    }
+    delete [] utf16_file_name;
+  }
+#else
+  file = fopen(file_name, "wb");
+#endif
+
+  if (file == 0)
+  {
+    REprintf( "ERROR: cannot open file '%s' for write\n", file_name);
     return FALSE;
   }
 
@@ -809,6 +824,10 @@ BOOL LASwriterLAS::open(ByteStreamOut* stream, const LASheader* header, U32 comp
       return FALSE;
     }
 
+    // save the position in the stream at which the payload of this VLR was written
+
+    header->vlr_lasoriginal->position = stream->tell();
+
     // write the payload of this VLR which contains 176 bytes
 
     if (!stream->put64bitsLE((U8*)&(header->vlr_lasoriginal->number_of_point_records)))
